package com.cardiff.client_project.service.imp;

import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.service.CommonAdminHospitalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class CommonAdminHospitalServiceImp implements CommonAdminHospitalService {

    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Override
    public List<HospitalDTO> getAllHospitals() {
        String sql = "SELECT * FROM hospital";
        return jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(HospitalDTO.class));
    }

    @Override
    public List<HospitalDTO> searchHospitals(String name, String location) {
        String sql = "SELECT * FROM hospital WHERE 1=1";
        if (name != null && !name.isEmpty()) {
            sql += " AND name LIKE '%" + name + "%'";
        }
        if (location != null && !location.isEmpty()) {
            sql += " AND location LIKE '%" + location + "%'";
        }
        return jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(HospitalDTO.class));
    }

    @Override
    public void addHospital(HospitalDTO hospital) {
        if (hospital.getName() == null || hospital.getAddress() == null || // 修改为 address
                hospital.getPhone() == null || hospital.getTotalBeds() <= 0 ||
                hospital.getAvailableBeds() < 0) {
            throw new IllegalArgumentException("Invalid hospital data: Missing or incorrect fields.");
        }

        double occupancyRate = 1.0 - (double) hospital.getAvailableBeds() / hospital.getTotalBeds();

        String sql = "INSERT INTO hospital (name, address, phone, totalBeds, availableBeds, occupancyRate) VALUES (?, ?, ?, ?, ?, ?)";
        jdbcTemplate.update(sql, hospital.getName(), hospital.getAddress(), hospital.getPhone(),
                hospital.getTotalBeds(), hospital.getAvailableBeds(), occupancyRate);
    }


    @Override
    public void updateHospital(HospitalDTO hospital) {
        if (hospital.getId() <= 0 || hospital.getName() == null || hospital.getLocation() == null ||
                hospital.getPhone() == null || hospital.getTotalBeds() <= 0 || hospital.getAvailableBeds() < 0) {
            throw new IllegalArgumentException("Invalid hospital data: Missing or incorrect fields.");
        }

        String sql = "UPDATE hospital SET name = ?, location = ?, phone = ?, totalBeds = ?, availableBeds = ?, occupancyRate = ? WHERE id = ?";
        double occupancyRate = 1.0 - (double) hospital.getAvailableBeds() / hospital.getTotalBeds();

        int rowsUpdated = jdbcTemplate.update(sql, hospital.getName(), hospital.getLocation(), hospital.getPhone(),
                hospital.getTotalBeds(), hospital.getAvailableBeds(), occupancyRate, hospital.getId());

        if (rowsUpdated == 0) {
            throw new IllegalArgumentException("No hospital found with ID " + hospital.getId());
        }
    }

    @Override
    public void deleteHospital(int id) {
        // Delete the specified record.
        String deleteSql = "DELETE FROM hospital WHERE id = ?";
        jdbcTemplate.update(deleteSql, id);

        // Reorder ID
        String reorderSql = "SET @new_id = 0; " +
                "UPDATE hospital SET id = (@new_id := @new_id + 1); " +
                "ALTER TABLE hospital AUTO_INCREMENT = 1;";
        for (String sql : reorderSql.split(";")) {
            if (!sql.trim().isEmpty()) {
                jdbcTemplate.execute(sql.trim());
            }
        }
    }



}
