package com.cardiff.client_project.service.imp;

import com.cardiff.client_project.constant.ResponseCode;
import com.cardiff.client_project.mapper.HospitalAdminMapper;
import com.cardiff.client_project.pojo.dto.SelectDTO;
import com.cardiff.client_project.pojo.entity.Hospital;
import com.cardiff.client_project.pojo.vo.HospitalAdminVO;

import com.cardiff.client_project.pojo.vo.HospitalVO;
import com.cardiff.client_project.pojo.vo.SelectVO;
import com.cardiff.client_project.service.HospitalAdminService;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class HospitalAdminServiceImpl implements HospitalAdminService {

    @Autowired
    private HospitalAdminMapper hospitalAdminMapper;
    @Autowired
    PasswordEncoder passwordEncoder;


    /**
     * Query admin information
     * @return
     */
    public Result selectAllAdmin() {
        List<HospitalAdminVO> allAdmins = hospitalAdminMapper.selectAllAdmin().stream()
                .map(this::convertToAdminVO)
                .collect(Collectors.toList());

        return allAdmins.isEmpty() ? Result.error(ResponseCode.ERROR) : Result.success(allAdmins);

    }

    private HospitalAdminVO convertToAdminVO(HospitalAdminVO adminVO) {
        adminVO.setStatus_str(adminVO.getStatus() == 1 ? "ACTIVE" : "INACTIVE");
        return adminVO;
    }


    /**
     * Query hospital information
     * @return
     */

    public Result selectAllHospital() {
        List<Hospital> hospitals = hospitalAdminMapper.selectAllHospital();
        List<HospitalVO> hospitalVOS = hospitals.stream()
                .map(this::convertToHospitalVO)
                .collect(Collectors.toList());

        System.out.println("HospitalVO List: " + hospitalVOS);
        return hospitalVOS.isEmpty() ? Result.error(ResponseCode.ERROR) : Result.success(hospitalVOS);
    }

    private HospitalVO convertToHospitalVO(Hospital hospital) {
        HospitalVO hospitalVO = new HospitalVO();
        BeanUtils.copyProperties(hospital, hospitalVO);

        hospitalVO.setStatus_str(hospital.getStatus() == 1 ? "ACTIVE" : "INACTIVE");
        return hospitalVO;
    }

    /**
     * fuzzy query
     * @param selectDTO
     * @return
     */
    public Result selectByItem(SelectDTO selectDTO) {
        List<SelectVO> selectVos = hospitalAdminMapper.selectByItem(selectDTO);
        selectVos.forEach(selectVO -> {
            if (selectVO.getStatus() == 1) {
                selectVO.setStatus_str("ACTIVE");
            }
            if (selectVO.getStatus() == 0) {
                selectVO.setStatus_str("INACTIVE");
            }
        });

        if(!selectVos.isEmpty()){
            return Result.success(selectVos);
        }else {
            return Result.error(ResponseCode.ACCOUNT_NOT_EXISTS);
        }

    }
}